####
core
####

.. code-block:: python

    from mitm import core

.. automodule:: mitm.core

-----

.. autoclass:: mitm.core.Host
    :members:

.. autoclass:: mitm.core.Connection
    :members:

.. autoclass:: mitm.core.Flow(enum.Enum)
    :members:

.. autoclass:: mitm.core.Middleware(abc.ABC)
    :members:

.. autoclass:: mitm.core.InvalidProtocol(Exception)
    :members:

.. autoclass:: mitm.core.Protocol(abc.ABC)
    :members:
